@@ -36,7 +36,7 @@ use warnings;
 use Carp qw/croak/;
 use List::Util qw(max min);
 
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 my $DEG_IN_SCALE = 12;
 
@@ -537,14 +537,13 @@ diversion in coding.
 
 =head1 AUTHOR
 
-Jeremy Mates E<lt>jmates@cpan.orgE<gt>
+thrig - Jeremy Mates (cpan:JMATES) C<< <jmates at cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2013 Jeremy Mates
+Copyright (C) 2011-2015 Jeremy Mates
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.16 or, at
-your option, any later version of Perl 5 you may have available.
+This module is free software; you can redistribute it and/or modify it
+under the Artistic License (2.0).
 
 =cut
